'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var Breakout = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
      Tag = _props$as === void 0 ? 'div' : _props$as,
      _props$style = props.style,
      userStyles = _props$style === void 0 ? {} : _props$style,
      children = props.children,
      rest = _objectWithoutPropertiesLoose(props, ["as", "style", "children"]);

  var style = _extends({
    width: '100vw',
    marginLeft: '50%',
    transform: 'translateX(-50%)'
  }, userStyles);

  return React__default.createElement(Tag, Object.assign({}, _extends(_extends({}, rest), {}, {
    ref: ref,
    style: style
  })), children);
});

var keyToFlexLookup = {
  top: 'flex-start',
  center: 'center',
  bottom: 'flex-end',
  stretch: 'stretch'
};

function translateToFlex(key) {
  return keyToFlexLookup[key];
}

var HStack = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
      Tag = _props$as === void 0 ? 'div' : _props$as,
      _props$alignment = props.alignment,
      alignment = _props$alignment === void 0 ? 'stretch' : _props$alignment,
      _props$style = props.style,
      userStyles = _props$style === void 0 ? {} : _props$style,
      children = props.children,
      rest = _objectWithoutPropertiesLoose(props, ["as", "alignment", "style", "children"]);

  var style = _extends({
    display: 'flex',
    flexDirection: 'row',
    alignItems: translateToFlex(alignment),
    justifyContent: 'center'
  }, userStyles);

  return React__default.createElement(Tag, Object.assign({}, _extends(_extends({}, rest), {}, {
    ref: ref,
    style: style
  })), children);
});

var keyToFlexLookup$1 = {
  leading: 'flex-start',
  center: 'center',
  trailing: 'flex-end',
  stretch: 'stretch'
};

function translateToFlex$1(key) {
  return keyToFlexLookup$1[key];
}

var VStack = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
      Tag = _props$as === void 0 ? 'div' : _props$as,
      _props$alignment = props.alignment,
      alignment = _props$alignment === void 0 ? 'stretch' : _props$alignment,
      _props$style = props.style,
      userStyles = _props$style === void 0 ? {} : _props$style,
      children = props.children,
      rest = _objectWithoutPropertiesLoose(props, ["as", "alignment", "style", "children"]);

  var style = _extends({
    display: 'flex',
    flexDirection: 'column',
    alignItems: translateToFlex$1(alignment),
    justifyContent: 'flex-start'
  }, userStyles);

  return React__default.createElement(Tag, Object.assign({}, _extends(_extends({}, rest), {}, {
    ref: ref,
    style: style
  })), children);
});

var Flex = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$grow = props.grow,
      grow = _props$grow === void 0 ? '1' : _props$grow,
      _props$shrink = props.shrink,
      shrink = _props$shrink === void 0 ? '1' : _props$shrink,
      _props$basis = props.basis,
      basis = _props$basis === void 0 ? '0%' : _props$basis,
      _props$as = props.as,
      Tag = _props$as === void 0 ? 'div' : _props$as,
      _props$style = props.style,
      userStyles = _props$style === void 0 ? {} : _props$style,
      children = props.children,
      rest = _objectWithoutPropertiesLoose(props, ["grow", "shrink", "basis", "as", "style", "children"]);

  var style = _extends({
    flex: grow + " " + shrink + " " + basis
  }, userStyles);

  return React__default.createElement(Tag, Object.assign({}, _extends(_extends({}, rest), {}, {
    ref: ref,
    style: style
  })), children);
});

var Spacer = /*#__PURE__*/React.forwardRef(function (props, ref) {
  return React__default.createElement(Flex, Object.assign({}, _extends(_extends({}, props), {}, {
    ref: ref
  })));
});

var Screen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
      Tag = _props$as === void 0 ? 'div' : _props$as,
      _props$style = props.style,
      userStyles = _props$style === void 0 ? {} : _props$style,
      children = props.children,
      rest = _objectWithoutPropertiesLoose(props, ["as", "style", "children"]);

  var style = _extends({
    height: '100vh',
    width: '100vw',
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'center'
  }, userStyles);

  return React__default.createElement(Tag, Object.assign({}, _extends(_extends({}, rest), {}, {
    ref: ref,
    style: style
  })), children);
});

var Tiles = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
      Tag = _props$as === void 0 ? 'div' : _props$as,
      _props$min = props.min,
      min = _props$min === void 0 ? '250px' : _props$min,
      _props$style = props.style,
      userStyles = _props$style === void 0 ? {} : _props$style,
      children = props.children,
      rest = _objectWithoutPropertiesLoose(props, ["as", "min", "style", "children"]);

  var style = _extends({
    display: 'grid',
    gridTemplateColumns: "repeat(auto-fit, minmax(min(" + min + ", 100%), 1fr))"
  }, userStyles);

  return React__default.createElement(Tag, Object.assign({}, _extends(_extends({}, rest), {}, {
    ref: ref,
    style: style
  })), children);
});

exports.Breakout = Breakout;
exports.Flex = Flex;
exports.HStack = HStack;
exports.Screen = Screen;
exports.Spacer = Spacer;
exports.Tiles = Tiles;
exports.VStack = VStack;
//# sourceMappingURL=layout-blocks.cjs.development.js.map
